import { Duration, IResource, Resource, ResourceProps } from 'aws-cdk-lib';
import { IStateMachine, StateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { IConstruct } from 'constructs';
import { IssueTrigger } from './issue-trigger';
export interface IIssueHandler extends IResource {
    readonly handler: IStateMachine;
    readonly name: string;
}
export interface IIssueParser extends IResource {
    readonly handler: IStateMachine;
    readonly matchType: string;
    bind(node: IConstruct): IssueTrigger[];
}
export interface IssueManagerProps extends ResourceProps {
    readonly handlers?: IIssueHandler[];
    readonly name?: string;
    readonly parsers?: IIssueParser[];
    readonly timeout?: Duration;
}
export declare class IssueManager extends Resource {
    private readonly _handlers;
    private readonly _parsers;
    private readonly determineIssueType;
    private readonly executeIssueHandlers;
    private readonly handleIssue;
    readonly name?: string;
    readonly timeout?: Duration;
    constructor(scope: IConstruct, id: string, props?: IssueManagerProps);
    /**
     * Adds a destination that handles issues that get passed to the issue
     * manager.
     *
     * @param handler The destination that will handle issues that have been
     * raised.
     */
    addHandler(handler: IIssueHandler): void;
    /**
     * Adds a parser that is used to transform incoming issues into a known
     * format that can be passed to the destinations where they will be consumed
     * by users.
     *
     * @param parser A parser that handles a specific type of event that should
     * trigger an issue to be raised.
     */
    addIssueParser(parser: IIssueParser): void;
    protected addEventRules(stateMachine: StateMachine): void;
}
