import { Duration } from 'aws-cdk-lib';
import { Condition, IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { IConstruct } from 'constructs';
import { DescriptionBuilder } from './description-builder';
import { IssueParserPluginBase, IssueParserPluginBaseProps } from './issue-parser-plugin-base';
import { IssueHandlerOverride } from '../issue-handler-override';
import { IIssueParser } from '../issue-manager';
import { IssueTrigger } from '../issue-trigger';
export declare class InspectorSeverity {
    static readonly UNTRIAGED: InspectorSeverity;
    static readonly INFORMATIONAL: InspectorSeverity;
    static readonly LOW: InspectorSeverity;
    static readonly MEDIUM: InspectorSeverity;
    static readonly HIGH: InspectorSeverity;
    static readonly CRITICAL: InspectorSeverity;
    static of(standardized: string, original: string, priority: number): InspectorSeverity;
    static all(): InspectorSeverity[];
    static custom(...levels: InspectorSeverity[]): InspectorSeverity[];
    static threshold(level: InspectorSeverity): InspectorSeverity[];
    readonly original: string;
    readonly priority: number;
    readonly standardized: string;
    private constructor();
    buildCondition(path: string): Condition;
}
export interface InspectorFindingEventOptions {
    readonly overrides?: IssueHandlerOverride[];
    readonly severity?: InspectorSeverity[];
}
export interface InspectorFindingProps extends IssueParserPluginBaseProps {
}
export declare class InspectorFinding extends IssueParserPluginBase implements IIssueParser {
    static readonly MATCH_TYPE: string;
    static readonly SEVERITIES: InspectorSeverity[];
    readonly name?: string;
    readonly timeout?: Duration;
    readonly handler: IStateMachine;
    get triggers(): IssueTrigger[];
    constructor(scope: IConstruct, id: string, props?: InspectorFindingProps);
    protected addDefaultTrigger(): IssueTrigger;
    protected buildDescription(): DescriptionBuilder;
    private buildPackageVulnerabilityDetails;
    private buildRemediation;
    private buildResources;
    registerIssueTrigger(id: string, options?: InspectorFindingEventOptions): IssueTrigger;
}
