import { Duration } from 'aws-cdk-lib';
import { Condition, IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { IConstruct } from 'constructs';
import { DescriptionBuilder } from './description-builder';
import { IssueParserPluginBase, IssueParserPluginBaseProps } from './issue-parser-plugin-base';
import { IssueHandlerOverride } from '../issue-handler-override';
import { IIssueParser } from '../issue-manager';
import { IssueTrigger } from '../issue-trigger';
export declare class OpenSearchEventSeverity {
    static readonly INFORMATIONAL: OpenSearchEventSeverity;
    static readonly LOW: OpenSearchEventSeverity;
    static readonly MEDIUM: OpenSearchEventSeverity;
    static readonly HIGH: OpenSearchEventSeverity;
    static of(standardized: string, original: string, priority: number): OpenSearchEventSeverity;
    static all(): OpenSearchEventSeverity[];
    static custom(...levels: OpenSearchEventSeverity[]): OpenSearchEventSeverity[];
    static threshold(level: OpenSearchEventSeverity): OpenSearchEventSeverity[];
    readonly original: string;
    readonly priority: number;
    readonly standardized: string;
    private constructor();
    buildCondition(path: string): Condition;
}
export interface OpenSearchEventTypeProps {
    readonly detailType: string;
    readonly eventName: string;
}
/**
 * Represents a type of event that can be generated in response to
 * circumstances happening on an AWS OpenSearch service cluster.
 *
 * @see [Monitoring OpenSearch Service events with Amazon EventBridge](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/monitoring-events.html)
 */
export declare class OpenSearchEventType {
    static readonly AUTO_TUNE: OpenSearchEventType;
    static readonly CLUSTER_RECOVERY: OpenSearchEventType;
    static readonly CUSTOM_INDEX_ROUTING: OpenSearchEventType;
    static readonly DISK_THROUGHPUT_THROTTLE: OpenSearchEventType;
    static readonly DOMAIN_UPDATE: OpenSearchEventType;
    static readonly EBS_BURST_BALANCE: OpenSearchEventType;
    static readonly FAILED_SHARD_LOCK: OpenSearchEventType;
    static readonly HIGH_JVM_USAGE: OpenSearchEventType;
    static readonly HIGH_SHARED_COUNT: OpenSearchEventType;
    static readonly INSUFFICIENT_GARBAGE_COLLECTION: OpenSearchEventType;
    static readonly KMS_KEY_INACCESSIBLE: OpenSearchEventType;
    static readonly LARGE_SHARD_SIZE: OpenSearchEventType;
    static readonly LOW_DISK_SPACE: OpenSearchEventType;
    static readonly LOW_DISK_WATERMARK_BREACH: OpenSearchEventType;
    static readonly NODE_RETIREMENT: OpenSearchEventType;
    static readonly SERVICE_SOFTWARE_UPDATE: OpenSearchEventType;
    static readonly VPC_ENDPOINT_CREATE: OpenSearchEventType;
    static readonly VPC_ENDPOINT_DELETE: OpenSearchEventType;
    static readonly VPC_ENDPOINT_UPDATE: OpenSearchEventType;
    static get all(): OpenSearchEventType[];
    static of(props: OpenSearchEventTypeProps): OpenSearchEventType;
    readonly detailType: string;
    readonly eventName: string;
    private constructor();
}
export interface OpenSearchEventRuleOptions {
    readonly overrides?: IssueHandlerOverride[];
    readonly severity?: OpenSearchEventSeverity[];
    readonly types?: OpenSearchEventType[];
}
export interface OpenSearchEventProps extends IssueParserPluginBaseProps {
}
export declare class OpenSearchEvent extends IssueParserPluginBase implements IIssueParser {
    static readonly MATCH_TYPE: string;
    static readonly SEVERITIES: OpenSearchEventSeverity[];
    readonly name?: string;
    readonly timeout?: Duration;
    readonly handler: IStateMachine;
    constructor(scope: IConstruct, id: string, props?: OpenSearchEventProps);
    protected addDefaultTrigger(): IssueTrigger;
    private addDomainDetails;
    protected buildDescription(): DescriptionBuilder;
    registerIssueTrigger(id: string, options?: OpenSearchEventRuleOptions): IssueTrigger;
}
