import { IConstruct } from 'constructs';
/**
 * Specifies the type of destination where alert manager can send
 * notifications.
 *
 * Corresponds with a config block inside an alert manager receiver
 * configuration.
 */
export declare class AlertManagerDestinationCategory {
    readonly name: string;
    /**
     * Sends notifications via email.
     *
     * Not currently supported by APS.
     */
    static readonly EMAIL: AlertManagerDestinationCategory;
    /**
     * Sends notifications using Opsgenie.
     *
     * Not currently supported by APS.
     */
    static readonly OPSGENIE: AlertManagerDestinationCategory;
    /**
     * Sends notifications using PagerDuty.
     *
     * Not currently supported by APS.
     */
    static readonly PAGERDUTY: AlertManagerDestinationCategory;
    /**
     * Sends notifications using Pushover.
     *
     * Not currently supported by APS.
     */
    static readonly PUSHOVER: AlertManagerDestinationCategory;
    /**
     * Sends notifications via Slack.
     *
     * Not currently supported by APS.
     */
    static readonly SLACK: AlertManagerDestinationCategory;
    /**
     * Sends notifications using Amazon SNS.
     */
    static readonly SNS: AlertManagerDestinationCategory;
    /**
     * Sends notifications via Telegram.
     *
     * Not currently supported by APS.
     */
    static readonly TELEGRAM: AlertManagerDestinationCategory;
    /**
     * Sends notifications using VictorOps.
     *
     * Not currently supported by APS.
     */
    static readonly VICTOROPS: AlertManagerDestinationCategory;
    /**
     * Sends notifications via a webhook.
     *
     * Not currently supported by APS.
     */
    static readonly WEBHOOK: AlertManagerDestinationCategory;
    /**
     * Sends notifications via WeChat.
     *
     * Not currently supported by APS.
     */
    static readonly WECHAT: AlertManagerDestinationCategory;
    /**
     * Sends notifications using Webex.
     *
     * Not currently supported by APS.
     */
    static readonly WEBEX: AlertManagerDestinationCategory;
    /**
     * An escape hatch method that allows specifying arbitrary values for the
     * type a receiver field a destination should be placed under.
     *
     * In the event that new destination types are added by alert manager, this
     * can be used to implement custom destinations in the event that it hasn't
     * had the chance to be implemented here.
     *
     * Whenever possible, it is recommended the static values provided be used.
     *
     * @param name The name of the key in a receiver config where the destination
     * being configured should be placed.
     * @returns An object that can be used when building a receiver that
     * specifies the given destination.
     */
    static of(name: string): AlertManagerDestinationCategory;
    /**
     * Creates a new instance of the AlertManagerDestinationCategory class.
     *
     * @param name The name of the category, as it would appear as a key in the
     * configuration for an alert manager receiver.
     */
    private constructor();
}
/**
 * Represents a destination where alert manager can send notifications.
 */
export interface IAlertManagerDestination {
    /**
     * The destination type being configured.
     *
     * Represents a config block in an alert manager receiver configuration.
     */
    readonly category: AlertManagerDestinationCategory;
    /**
     * Associates the destination with a construct that is handling the
     * configuration of alert manager.
     *
     * @param scope The construct handling alert manager configuration.
     * @returns An object representing the configured destination.
     */
    bind(scope: IConstruct): {
        [key: string]: any;
    };
}
