import { Resource, ResourceProps } from 'aws-cdk-lib';
import { IConstruct } from 'constructs';
import { IIpamPool, Ipam } from '../ec2';
import { IIpv4CidrAssignment } from '../ec2/lib/cidr-assignment';
import { ResourceShare } from '../ram';
export interface IpAddressManagerSharingProps {
    readonly allowExternalPricipals?: boolean;
    readonly enabled?: boolean;
}
export interface IpAddressManagerProps extends ResourceProps {
    readonly clientVpnAllocationMask?: number;
    readonly regions?: string[];
    readonly sharing?: IpAddressManagerSharingProps;
    readonly vpcAllocationMask?: number;
    readonly vpcPoolCidrs?: string[];
    readonly vpcRegionMask?: number;
    readonly vpnPoolCidrs?: string[];
}
export interface AddPoolOptions {
    readonly cidrs?: string[];
    readonly defaultNetmaskLength?: number;
}
export interface AllocatePrivateNetworkOptions {
    readonly netmask?: number;
    readonly pool?: string;
}
export interface GetClientVpnConfigurationOptions {
    readonly netmask?: number;
}
export interface GetClientVpnConfigurationResult {
    readonly cidr: string;
}
export interface GetVpcConfigurationOptions {
    readonly netmask?: number;
}
export declare class IpAddressManager extends Resource {
    static readonly DEFAULT_CLIENT_VPN_ALLOCATION_MASK: number;
    static readonly DEFAULT_VPC_ALLOCATION_MASK: number;
    static readonly DEFAULT_VPC_POOL_CIDRS: string[];
    static readonly DEFAULT_VPN_POOL_CIDRS: string[];
    private static readonly PRIVATE_VPN_POOL_ID;
    private readonly privateVpcPool;
    private readonly vpnPoolCidrs?;
    private get privateVpnPool();
    readonly allowExternalPricipals: boolean;
    readonly clientVpnAllocationMask: number;
    readonly sharingEnabled: boolean;
    readonly vpcAllocationMask: number;
    readonly ipam: Ipam;
    get resourceShare(): ResourceShare | undefined;
    constructor(scope: IConstruct, id: string, props?: IpAddressManagerProps);
    addRegion(region: string): void;
    private getOrCreatePrivateVpnPool;
    protected privateVpcPoolForRegion(region: string): IIpamPool;
    protected privateVpnPoolForRegion(region: string): IIpamPool;
    protected privateVpcPoolForEnvironment(account: string, region: string): IIpamPool;
    protected privateVpnPoolForEnvironment(account: string, region: string): IIpamPool;
    getClientVpnConfiguration(scope: IConstruct, id: string, options?: GetClientVpnConfigurationOptions): IIpv4CidrAssignment;
    getVpcConfiguration(scope: IConstruct, id: string, options?: GetVpcConfigurationOptions): IIpv4CidrAssignment;
    protected registerAccount(account: string, pool: IIpamPool): void;
    registerCidr(scope: IConstruct, id: string, cidr: string): void;
}
