import { CfnTransitGatewayVpcAttachment } from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
import { TransitGatewayAttachmentResource, TransitGatewayAttachmentResourceProps } from './transit-gateway-attachment-base';
/**
 * Configuration for TransitGatewayVpcAttachment resource.
 */
export interface TransitGatewayVpcAttachmentProps extends TransitGatewayAttachmentResourceProps {
}
/**
 * Attaches a VPC to a transit gateway.
 *
 * If you attach a VPC with a CIDR range that overlaps the CIDR range of a VPC
 * that is already attached, the new VPC CIDR range is not propagated to the
 * default propagation route table.
 */
export declare class TransitGatewayVpcAttachment extends TransitGatewayAttachmentResource {
    /**
     * The underlying TransitGatewayVpcAttachment CloudFormation resource.
     *
     * @see [AWS::EC2::TransitGatewayVpcAttachment](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-transitgatewayvpcattachment.html)
     *
     * @group Resources
     */
    readonly resource: CfnTransitGatewayVpcAttachment;
    /**
     * The ARN of this Transit Gateway Attachment.
     */
    readonly transitGatewayAttachmentArn: string;
    /**
     * The ID of this Transit Gateway Attachment.
     */
    readonly transitGatewayAttachmentId: string;
    /**
     * Creates a new instance of the TransitGatewayVpcAttachment class.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in the construct tree.
     * @param id A name to be associated with the stack and used in resource naming. Must be unique
     * within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: Construct, id: string, props: TransitGatewayVpcAttachmentProps);
}
